require "capistrano/doctor/output_helpers"

include Capistrano::DSL

# @author Clive Walkden
module SozoMagento2
    # Class to out key information at the end of the deploy:check command
    module Info
        # Class to out key information at the end of the deploy:check command
        class Info
            WHITELIST = %i(
                branch
                environment
                handle_cron
                slack_channel
                url
              ).freeze
              private_constant :WHITELIST
            
            include Capistrano::Doctor::OutputHelpers

            # Initialize the class with access to env data
            def initialize(env=Capistrano::Configuration.env)
                @env = env
            end

            # Output the key information in the CLI
            def call
                title("Deployment Info")

                values = inspect_all_values

                table(values.keys.sort_by(&:to_s)) do |key, row|
                    row.yellow if values[key] == "\"production\""
                    row << key.inspect
                    row << ''
                    row << values[key]
                end
                
                puts("")
                warning("Make sure you check these values before deploying!")
                puts("")
            end

            private

            attr_reader :env

            # Read all variables in
            def variables
                env.variables
            end

            # Only include variables in the whitelist
            def inspect_all_values
                variables.keys.each_with_object({}) do |key, inspected|
                    if WHITELIST.include?(key)
                        inspected[key] = variables.peek(key).inspect
                    end
                end
            end
        end
    end
end